{% extends "admin/import_export/change_list.html" %}

{% block object-tools-items %}
    <div class="btn-group float-right">
        {% include "admin/import_export/change_list_import_item.html" %}
        {% include "admin/import_export/change_list_export_item.html" %}
        {{ block.super }}
    </div>
{% endblock %}
