{% load i18n static jazzmin admin_urls %}
{% get_current_language as LANGUAGE_CODE %}
{% get_current_language_bidi as LANGUAGE_BIDI %}
{% get_jazzmin_settings as jazzmin_settings %}
{% get_jazzmin_ui_tweaks as jazzmin_ui %}

<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}" {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="x-ua-compatible" content="ie=edge">

    <title>{% block title %}{{ title }} | {% trans 'Log in again' %}{% endblock %}</title>

    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="{% static "vendor/fontawesome-free/css/all.min.css" %}">

    <!-- Bootstrap and adminLTE -->
    <link rel="stylesheet" href="{% static "vendor/adminlte/css/adminlte.min.css" %}">

    <!-- Bootswatch theme -->
    {% if jazzmin_ui.theme.name != 'default' %}
        <link rel="stylesheet" href="{{ jazzmin_ui.theme.src }}" id="jazzmin-theme" />
    {% endif %}

    {% if jazzmin_ui.dark_mode_theme.name %}
        <link rel="stylesheet" href="{{ jazzmin_ui.dark_mode_theme.src }}" id="jazzmin-dark-mode-theme" media="(prefers-color-scheme: dark)"/>
    {% endif %}

    <!-- Custom fixes for django -->
    <link rel="stylesheet" href="{% static "jazzmin/css/main.css" %}">

    {% if jazzmin_settings.custom_css %}
        <!-- Custom CSS -->
        <link rel="stylesheet" href="{% static jazzmin_settings.custom_css %}">
    {% endif %}

    <!-- favicons -->
    <link rel="shortcut icon" href="{% static jazzmin_settings.site_logo %}" type="image/png">
    <link rel="icon" href="{% static jazzmin_settings.site_logo %}" sizes="32x32" type="image/png">

    <!-- Google Font: Source Sans Pro -->
    <link href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700" rel="stylesheet">

    {% block extrastyle %} {% endblock %}
    {% block extrahead %} {% endblock %}
</head>
<body class="hold-transition jazzmin-login-page">

<div class="login-box">
    <div class="login-logo">
        <h1>{{ jazzmin_settings.site_header }}</h1>
    </div>

    <div class="card">
        <div class="card-body">
            <p class="login-box-msg">{{ jazzmin_settings.welcome_sign }}</p>
            <form action="{{ app_path }}" method="post">
                {% csrf_token %}
                {% if form.errors %}

                    {% if form.username.errors %}
                    <div class="callout callout-danger">
                        <p>{{ form.username.label }}: {{ form.username.errors|join:', ' }}</p>
                    </div>
                    {% endif %}

                    {% if form.password.errors %}
                    <div class="callout callout-danger">
                        <p>{{ form.password.label }}: {{ form.password.errors|join:', ' }}</p>
                    </div>
                    {% endif %}

                    {% if form.non_field_errors %}
                    <div class="callout callout-danger">
                        {% for error in form.non_field_errors %}
                            <p>{{ error }}</p>
                        {% endfor %}
                    </div>
                    {% endif %}

                {% endif %}
                <div class="input-group mb-3">
                    <input type="text" name="username" class="form-control" placeholder="{{ form.username.label }}" required>
                    <div class="input-group-append">
                        <div class="input-group-text">
                            <span class="fas fa-user"></span>
                        </div>
                    </div>
                </div>
                <div class="input-group mb-3">
                    <input type="password" name="password" class="form-control" placeholder="{{ form.password.label }}" required>
                    <div class="input-group-append">
                        <div class="input-group-text">
                            <span class="fas fa-lock"></span>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <button type="submit" class="btn {{ jazzmin_ui.button_classes.primary }} btn-block">{% trans "Log in" %}</button>
                    </div>
                </div>
            </form>

        </div>
    </div>
</div>

<!-- jQuery -->
<script src="{% static "admin/js/vendor/jquery/jquery.js" %}"></script>
<!-- Bootstrap 4 -->
<script src="{% static 'vendor/bootstrap/js/bootstrap.min.js' %}"></script>
<!-- AdminLTE App -->
<script src="{% static 'vendor/adminlte/js/adminlte.min.js' %}"></script>

{% if jazzmin_settings.custom_js %}
<script src="{% static jazzmin_settings.custom_js %}"></script>
{% endif %}

</body>
</html>
